Calculator

Struct Calculator 

pub struct Calculator { /* private fields */ }

Implementations

Source

impl Calculator

pub fn new(input: impl ToString) -> Result<Self>

This function creates a new Calculator instance, and automaticly parses the passed in string.

pub fn into_inner(&self) -> Vec<Expression>

Returns the parsed expressions from the Calculator instance

pub fn calculate(&self, variable_value: Option<f64>) -> Result<f64>

Calculates the result based on the parsed string. The reason this function is separate, is that you can use different variable values for calculations, without reparsing the data.